@@ -5,9 +5,10 @@ import os
 import configparser
 from loguru import logger
 import sys
+from pinecone.utils.tracing import init_tracer
+init_tracer()
 from pinecone.specs.service import Service  # noqa
 from pinecone.specs.traffic_router import TrafficRouter  # noqa
-
 from .constants import Config
 
 __all__ = ["init"]
