@@ -85,6 +85,8 @@ class VectorIndex(Index):
 
     @staticmethod
     def validate_ids(ids: Iterable[str]):
+        if MAX_ID_LENGTH == 0:
+            return  # no limit
         if any(len(id_) > MAX_ID_LENGTH for id_ in ids):
             raise ValueError(f"Vector IDs should be no longer than {MAX_ID_LENGTH} characters")
 
