@@ -24,7 +24,7 @@ def start(servlet_spec: ServletSpec, wal=False, persistent_dir=None, num_replica
         asyncio.set_event_loop(loop)
 
     if wal:
-        servlet = WALServlet(servlet_spec, num_replicas, persistent_dir)
+        servlet = WALServlet(servlet_spec, num_replicas, persistent_dir, volume_request=wal)
         logger.info(f"Before reload: {servlet_spec.get_stats()}")
         servlet.write_offset(servlet.replica, 0)  # replay all the messages
         request_backlog = list(servlet.load_sync(sync_handler))
@@ -34,6 +34,7 @@ def start(servlet_spec: ServletSpec, wal=False, persistent_dir=None, num_replica
         servlet = ZMQServlet(servlet_spec)
 
     loop.create_task(servlet.poll())
+    loop.create_task(servlet.refresh_dns())
     loop.run_forever()
     if servlet.exception is not None and type(servlet.exception) == RestartException:
         raise RestartException
